Crate dora_cli

Crate dora_cli 

Modules

output
session

Structs

Args
BuildConfig
Configuration for a build invocation. Set dataflow and override only the fields you care about using struct-update syntax:
CommandNew
RunCommand
Run a dataflow locally in isolation.
WsSession
A WebSocket session to the coordinator.

Traits

Executable

Functions

build
lib_main
lib_main_from_argv
Parse a command line and run it, the way both dora entry points need to.
run