Modules
Structs
- Args
- Build
Config - Configuration for a
buildinvocation. Setdataflowand override only the fields you care about using struct-update syntax: - Command
New - RunCommand
- Run a dataflow locally in isolation.
- WsSession
- A WebSocket session to the coordinator.
Traits
Functions
- build
- lib_
main - lib_
main_ from_ argv - Parse a command line and run it, the way both dora entry points need to.
- run